%global srcname pillow
%bcond_with doc

Summary:        Python Imaging Library
Name:           python-%{srcname}
Version:        10.2.0
Release:        1%{?dist}
License:        MIT
URL:            http://python-pillow.github.io/
Source0:        https://github.com/python-pillow/Pillow/archive/%{version}/Pillow-%{version}.tar.gz

BuildRequires:  gcc
BuildRequires:  freetype-devel ghostscript lcms2-devel libimagequant-devel libjpeg-devel
BuildRequires:  libraqm-devel libtiff-devel libwebp-devel openjpeg2-devel tk-devel zlib-devel
BuildRequires:  python3-cffi python3-devel python3-numpy python3-olefile python3-pytest 
BuildRequires:  python3-tkinter python3-qt5 python3-setuptools
%if %{with doc}
BuildRequires:  make
BuildRequires:  python3-sphinx python3-sphinx-copybutton python3-sphinx_rtd_theme python3-sphinx-removed-in
%endif
Requires:       ghostscript


%description
The Python Imaging Library adds image processing capabilities to your 
Python interpreter. This library provides extensive file format support,
an efficient internal representation, and fairly powerful image processing
capabilities. The core image library is designed for fast access to data
stored in a few basic pixel formats. It should provide a solid foundation
for a general image processing tool.

%package -n python3-%{srcname}
Summary:        Python 3 image processing library
Provides:       python3-imaging = %{version}-%{release}
Requires:       python3-olefile

%description -n python3-%{srcname}
The Python Imaging Library adds image processing capabilities to your 
Python interpreter. This library provides extensive file format support,
an efficient internal representation, and fairly powerful image processing
capabilities. The core image library is designed for fast access to data
stored in a few basic pixel formats. It should provide a solid foundation
for a general image processing tool.


%package -n python3-%{srcname}-devel
Summary:        Development files for %{srcname}
Requires:       python3-devel, libjpeg-devel, zlib-devel
Requires:       python3-%{srcname} = %{version}-%{release}
Provides:       python3-imaging-devel = %{version}-%{release}

%description -n python3-%{srcname}-devel
Development files for %{srcname}.


%package -n python3-%{srcname}-doc
Summary:        Documentation for %{srcname}
BuildArch:      noarch
Requires:       python3-%{srcname} = %{version}-%{release}
Provides:       python3-imaging-doc = %{version}-%{release}

%description -n python3-%{srcname}-doc
Documentation for %{srcname}.


%package -n python3-%{srcname}-tk
Summary:        Tk interface for %{srcname}
Requires:       python3-tkinter
Requires:       python3-%{srcname} = %{version}-%{release}
Provides:       python3-imaging-tk = %{version}-%{release}

%description -n python3-%{srcname}-tk
Tk interface for %{srcname}.


%package -n python3-%{srcname}-qt
Summary:        Qt %{srcname} image wrapper
Requires:       python3-qt5
Requires:       python3-%{srcname} = %{version}-%{release}
Provides:       python3-imaging-qt = %{version}-%{release}

%description -n python3-%{srcname}-qt
Qt %{srcname} image wrapper.


%prep
%autosetup -p1 -n Pillow-%{version}


%build
%py3_build

%if %{with doc}
PYTHONPATH=$(echo $PWD/build/lib.linux-*) make -C docs html BUILDDIR=_build_py3 SPHINXBUILD=sphinx-build-%python3_version
rm -f docs/_build_py3/html/.buildinfo
%endif


%install
install -d %{buildroot}/%{_includedir}/python%{__default_python3_version}/Imaging
install -m 644 src/libImaging/*.h %{buildroot}/%{_includedir}/python%{__default_python3_version}/Imaging
%py3_install


%check
ln -s $PWD/Images $(echo $PWD/build/lib.linux-*)/Images
cp -R $PWD/Tests $(echo $PWD/build/lib.linux-*)/Tests
cp -a $PWD/selftest.py $(echo $PWD/build/lib.linux-*)/selftest.py
pushd build/lib.linux-*
PYTHONPATH=$PWD %{__python3} selftest.py
popd
%pytest -v -k "not test_qt_image_qapplication" || :


%files -n python3-%{srcname}
%license docs/COPYING
%doc README.md CHANGES.rst
%{python3_sitearch}/PIL/
%{python3_sitearch}/pillow-%{version}-py%{python3_version}.egg-info/
%exclude %{python3_sitearch}/PIL/_imagingtk*
%exclude %{python3_sitearch}/PIL/ImageTk*
%exclude %{python3_sitearch}/PIL/SpiderImagePlugin*
%exclude %{python3_sitearch}/PIL/ImageQt*
%exclude %{python3_sitearch}/PIL/__pycache__/ImageTk*
%exclude %{python3_sitearch}/PIL/__pycache__/SpiderImagePlugin*
%exclude %{python3_sitearch}/PIL/__pycache__/ImageQt*

%files -n python3-%{srcname}-devel
%{_includedir}/python%{__default_python3_version}/Imaging/

%if %{with doc}
%files -n python3-%{srcname}-doc
%doc docs/_build_py3/html
%endif

%files -n python3-%{srcname}-tk
%{python3_sitearch}/PIL/_imagingtk*
%{python3_sitearch}/PIL/ImageTk*
%{python3_sitearch}/PIL/SpiderImagePlugin*
%{python3_sitearch}/PIL/__pycache__/ImageTk*
%{python3_sitearch}/PIL/__pycache__/SpiderImagePlugin*

%files -n python3-%{srcname}-qt
%{python3_sitearch}/PIL/ImageQt*
%{python3_sitearch}/PIL/__pycache__/ImageQt*

%changelog
* Wed Jan 24 2024 Wang Guodong <gordonwwang@tencent.com> - 10.2.0-1
- update to 10.2.0
- fix CVE-2023-50447

* Wed Sep 27 2023 Shuo Wang <abushwang@tencent.com> - 10.0.1-1
- update to 10.0.1

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.5.0-8
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.5.0-7
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Sep 04 2023 cunshunxia <cunshunxia@tencent.com> - 9.5.0-6
- Rebuilt for ghostscript 10.01.2

* Thu Aug 17 2023 kianli@tencent.com - 9.5.0-5
- Rebuilt for openjpeg2 2.5.0

* Wed Aug 02 2023 kianli <kianli@tencent.com> - 9.5.0-4
- Rebuilt for libtiff 4.5.1

* Fri Jul 21 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.5.0-3
- Rebuilt for python-qt5 5.15.9

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 9.5.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Apr 14 2023 Miaojun Dong <zoedong@tencent.com> - 9.5.0-1
- initial build
